.. _path_module:

:mod:`pyramid.path`
---------------------------

.. automodule:: pyramid.path

    .. attribute:: CALLER_PACKAGE

       A constant used by the constructor of
       :class:`pyramid.path.DottedNameResolver` and
       :class:`pyramid.path.AssetResolver`.

    .. autoclass:: DottedNameResolver
       :members:

    .. autoclass:: AssetResolver
       :members:

